create_map_rep_rpe_to_pct: Create a mapping from reps and rpe to pct_1rm

View source: R/pct1rm.R

create_map_rep_rpe_to_pctR Documentation

Create a mapping from reps and rpe to pct_1rm

Description

Create a mapping from reps and rpe to pct_1rm

Usage

create_map_rep_rpe_to_pct(pct_lookup_tab)

Arguments

pct_lookup_tab

A lookup table that contains columns reps, rpe and pct_1rm.

Value

A function taking arguments reps and rpe, returning a numeric vector.

Examples

resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_rts)

strength documentation built on Feb. 25, 2026, 5:07 p.m.