e1rm: Estimated one rep max

View source: R/e1rm.R

e1rmR Documentation

Estimated one rep max

Description

Estimated one rep max

Usage

e1rm(weight, reps, rpe, pct1rm_func)

e1rm_rts(...)

e1rm_helms(...)

e1rm_brzycki(...)

Arguments

weight

Numeric vector of weights, one entry per set.

reps

Numeric vector of reps, one entry per set.

rpe

Numeric vector of RPEs, one entry per set.

pct1rm_func

A function which takes reps,rpe and returns an estimated percentage of one rep max.

...

Arguments passed to e1rm().

Value

A numeric vector of estimated one rep max values for each set.

Examples

e1rm(c(400, 300), c(1, 10), c(9, 6), pct1rm_rts)
e1rm_rts(c(400, 300), c(1, 10), c(9, 6))
e1rm_helms(c(400, 300), c(1, 10), c(9, 6))
e1rm_brzycki(c(400, 300), c(1, 10), c(9, 6))

strength documentation built on Feb. 25, 2026, 5:07 p.m.