| hard_sets | R Documentation |
Number of hard sets
hard_sets(rpe, cutoff = 7)
rpe |
A numeric vector of set RPE values. |
cutoff |
RPE cutoff for what qualifies as a hard set. The boundary is included. |
A numeric value counting the number of hard sets.
hard_sets(c(6, 7, 10, 9, NA))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.