pct1rm_rts: Mapping from reps and rpe to pct_1rm.

pct1rm_rtsR Documentation

Mapping from reps and rpe to pct_1rm.

Description

pct1rm_rts() uses the table provided by reactive training systems. pct1rm_helms() uses the table provided in a paper by Helms and colleagues. pct1rm_brzycki() uses the table provided by Brzycki in his book.

Usage

pct1rm_rts(reps, rpe)

pct1rm_helms(reps, rpe)

pct1rm_brzycki(reps, rpe)

Arguments

reps

A vector of repetitions performed in a set.

rpe

A vector of ratings of perceived exertion.

Details

reps must be length 1 or the same length as rpe. RPE must be length 1 or the same length as reps.

Value

A numeric vector listing the percentage of one 1 rep max.

Examples

pct1rm_rts(reps = 10, rpe = 8)
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_rts)
pct1rm_helms(reps = 5, rpe = 8)
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_rts)
pct1rm_helms(reps = 5, rpe = 8)
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_brzycki)

strength documentation built on Feb. 25, 2026, 5:07 p.m.