| create_map_rep_rpe_to_pct | R Documentation |
Create a mapping from reps and rpe to pct_1rm
create_map_rep_rpe_to_pct(pct_lookup_tab)
pct_lookup_tab |
A lookup table that contains columns reps, rpe and pct_1rm. |
A function taking arguments reps and rpe, returning a numeric vector.
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_rts)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.