| pct1rm_rts | R Documentation |
pct1rm_rts() uses the table provided by reactive training systems. pct1rm_helms() uses the table provided in a paper by Helms and colleagues. pct1rm_brzycki() uses the table provided by Brzycki in his book.
pct1rm_rts(reps, rpe)
pct1rm_helms(reps, rpe)
pct1rm_brzycki(reps, rpe)
reps |
A vector of repetitions performed in a set. |
rpe |
A vector of ratings of perceived exertion. |
reps must be length 1 or the same length as rpe. RPE must be length 1 or the same length as reps.
A numeric vector listing the percentage of one 1 rep max.
pct1rm_rts(reps = 10, rpe = 8)
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_rts)
pct1rm_helms(reps = 5, rpe = 8)
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_rts)
pct1rm_helms(reps = 5, rpe = 8)
resulting_function <- create_map_rep_rpe_to_pct(pct_lookup_brzycki)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.